==> igniteui-react-18.2.2-beta.0.tgz: package/esm2015/lib/Calendar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CalendarBase } from "./CalendarBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarHeaderOrientation_$type } from "./CalendarHeaderOrientation";
import { CalendarOrientation_$type } from "./CalendarOrientation";
import { CalendarActiveView_$type } from "./CalendarActiveView";
import { CalendarFormatOptions } from "./CalendarFormatOptions";
import { CalendarResourceStrings } from "./CalendarResourceStrings";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentDataValueChangedEventArgs } from "./ComponentDataValueChangedEventArgs";
/**
 * @hidden
 */
export let Calendar = /*@__PURE__*/ (() => {
    class Calendar extends CalendarBase {
        constructor() {
            super(...arguments);
            this.change = null;
        }
        get w() {
            let ret_ = this.f.m("value");
            return ret_;
        }
        set w(a) {
            let value_ = a;
            this.f.u("value", value_);
        }
        get l() {
            let ret_ = this.f.m("values");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.f.u("values", value_);
        }
        get v() {
            let ret_ = this.f.m("activeDate");
            return ret_;
        }
        set v(a) {
            let value_ = a;
            this.f.u("activeDate", value_);
        }
        get u() {
            let ret_ = this.f.m("hideOutsideDays");
            return ret_;
        }
        set u(a) {
            let value_ = a;
            this.f.u("hideOutsideDays", value_);
        }
        get t() {
            let ret_ = this.f.m("hideHeader");
            return ret_;
        }
        set t(a) {
            let value_ = a;
            this.f.u("hideHeader", value_);
        }
        get o() {
            let ret_ = this.f.m("headerOrientation");
            ret_ = enumGetBox(CalendarHeaderOrientation_$type, EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, this.f.f(CalendarHeaderOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, ret_);
        }
        set o(a) {
            let value_ = enumGetBox(CalendarHeaderOrientation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("headerOrientation", value_);
        }
        get p() {
            let ret_ = this.f.m("orientation");
            ret_ = enumGetBox(CalendarOrientation_$type, EnumUtil.getEnumValue(CalendarOrientation_$type, this.f.f(CalendarOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarOrientation_$type, ret_);
        }
        set p(a) {
            let value_ = enumGetBox(CalendarOrientation_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("orientation", value_);
        }
        get x() {
            let ret_ = this.f.m("visibleMonths");
            return ret_;
        }
        set x(a) {
            let value_ = a;
            this.f.u("visibleMonths", value_);
        }
        get m() {
            let ret_ = this.f.m("activeView");
            ret_ = enumGetBox(CalendarActiveView_$type, EnumUtil.getEnumValue(CalendarActiveView_$type, this.f.f(CalendarActiveView_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarActiveView_$type, ret_);
        }
        set m(a) {
            let value_ = enumGetBox(CalendarActiveView_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("activeView", value_);
        }
        get n() {
            let ret_ = this.f.l("formatOptions", (a) => new CalendarFormatOptions());
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.u("formatOptions", value_);
        }
        get q() {
            let ret_ = this.f.l("resourceStrings", (a) => new CalendarResourceStrings());
            return ret_;
        }
        set q(a) {
            let value_ = a;
            this.f.u("resourceStrings", value_);
        }
        get s() {
            let ret_ = this.f.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set s(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.f.u("size", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.q("change", (a) => this.change(this, ComponentDataValueChangedEventArgs.a(a)));
            }
            else {
                this.f.t("change");
            }
        }
    }
    Calendar.$t = /*@__PURE__*/ markType(Calendar, 'Calendar', CalendarBase.$);
    return Calendar;
})();

==> igniteui-react-18.3.0-beta.0.tgz: package/esm2015/lib/Calendar.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CalendarBase } from "./CalendarBase";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { CalendarHeaderOrientation_$type } from "./CalendarHeaderOrientation";
import { CalendarOrientation_$type } from "./CalendarOrientation";
import { CalendarActiveView_$type } from "./CalendarActiveView";
import { CalendarFormatOptions } from "./CalendarFormatOptions";
import { CalendarResourceStrings } from "./CalendarResourceStrings";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { ComponentDataValueChangedEventArgs } from "./ComponentDataValueChangedEventArgs";
/**
 * @hidden
 */
export let Calendar = /*@__PURE__*/ (() => {
    class Calendar extends CalendarBase {
        constructor() {
            super(...arguments);
            this.change = null;
        }
        get w() {
            let ret_ = this.f.n("value");
            return ret_;
        }
        set w(a) {
            let value_ = a;
            this.f.v("value", value_);
        }
        get l() {
            let ret_ = this.f.n("values");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.f.v("values", value_);
        }
        get v() {
            let ret_ = this.f.n("activeDate");
            return ret_;
        }
        set v(a) {
            let value_ = a;
            this.f.v("activeDate", value_);
        }
        get u() {
            let ret_ = this.f.n("hideOutsideDays");
            return ret_;
        }
        set u(a) {
            let value_ = a;
            this.f.v("hideOutsideDays", value_);
        }
        get t() {
            let ret_ = this.f.n("hideHeader");
            return ret_;
        }
        set t(a) {
            let value_ = a;
            this.f.v("hideHeader", value_);
        }
        get o() {
            let ret_ = this.f.n("headerOrientation");
            ret_ = enumGetBox(CalendarHeaderOrientation_$type, EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, this.f.f(CalendarHeaderOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarHeaderOrientation_$type, ret_);
        }
        set o(a) {
            let value_ = enumGetBox(CalendarHeaderOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("headerOrientation", value_);
        }
        get p() {
            let ret_ = this.f.n("orientation");
            ret_ = enumGetBox(CalendarOrientation_$type, EnumUtil.getEnumValue(CalendarOrientation_$type, this.f.f(CalendarOrientation_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarOrientation_$type, ret_);
        }
        set p(a) {
            let value_ = enumGetBox(CalendarOrientation_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("orientation", value_);
        }
        get x() {
            let ret_ = this.f.n("visibleMonths");
            return ret_;
        }
        set x(a) {
            let value_ = a;
            this.f.v("visibleMonths", value_);
        }
        get m() {
            let ret_ = this.f.n("activeView");
            ret_ = enumGetBox(CalendarActiveView_$type, EnumUtil.getEnumValue(CalendarActiveView_$type, this.f.f(CalendarActiveView_$type, ret_)));
            return EnumUtil.getEnumValue(CalendarActiveView_$type, ret_);
        }
        set m(a) {
            let value_ = enumGetBox(CalendarActiveView_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("activeView", value_);
        }
        get n() {
            let ret_ = this.f.m("formatOptions", (a) => new CalendarFormatOptions());
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.f.v("formatOptions", value_);
        }
        get q() {
            let ret_ = this.f.m("resourceStrings", (a) => new CalendarResourceStrings());
            return ret_;
        }
        set q(a) {
            let value_ = a;
            this.f.v("resourceStrings", value_);
        }
        get s() {
            let ret_ = this.f.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.f.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set s(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.f.v("size", value_);
        }
        changeChanged() {
            if (this.change != null) {
                this.f.r("change", (a) => this.change(this, ComponentDataValueChangedEventArgs.a(a)));
            }
            else {
                this.f.u("change");
            }
        }
    }
    Calendar.$t = /*@__PURE__*/ markType(Calendar, 'Calendar', CalendarBase.$);
    return Calendar;
})();
